@@ -1,37 +1,37 @@
 $VAR1 = {
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'scriptAlias' => 'cgi-bin',
-          'version' => '0.7',
-          'floodtime' => 10,
-          'config' => '/var/www/cgi-bin/config/settings.pl',
-          'admin' => {
-                       'email' => 'dirk.lze@gmail.com',
-                       'firstname' => 'Dirk',
-                       'name' => 'Lindner',
-                       'password' => 'testpass'
-                     },
           'cgi' => {
                      'alias' => 'cgi-bin',
                      'style' => 'mysql',
-                     'title' => 'MySQL::Admin',
+                     'serverName' => 'http://localhost',
+                     'expires' => '+1y',
                      'DocumentRoot' => '/var/www/htdocs',
                      'bin' => '/var/www/cgi-bin',
-                     'expires' => '+1y',
-                     'serverName' => 'http://localhost',
+                     'title' => 'MySQL::Admin',
                      'cookiePath' => '/'
                    },
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
           'database' => {
-                          'CurrentPass' => 'wertvoll',
-                          'name' => 'LZE',
-                          'host' => 'localhost',
                           'password' => 'wertvoll',
-                          'CurrentUser' => 'root',
-                          'user' => 'root',
                           'CurrentHost' => 'localhost',
-                          'CurrentDb' => 'LZE'
+                          'host' => 'localhost',
+                          'CurrentDb' => 'LZE',
+                          'CurrentPass' => 'wertvoll',
+                          'user' => 'root',
+                          'CurrentUser' => 'root',
+                          'name' => 'LZE'
                         },
+          'admin' => {
+                       'email' => 'dirk.lze@gmail.com',
+                       'name' => 'Lindner',
+                       'firstname' => 'Dirk',
+                       'password' => 'testpass'
+                     },
+          'language' => 'en',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'floodtime' => 10,
+          'config' => '/var/www/cgi-bin/config/settings.pl',
           'session' => '/var/www/cgi-bin/config/session.pl',
-          'language' => 'en'
+          'scriptAlias' => 'cgi-bin',
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'version' => '0.71'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
