@@ -7,7 +7,7 @@ CREATE TABLE `actions` (
   `sub` varchar(25) NOT NULL DEFAULT 'main',
   `id` int(11) NOT NULL AUTO_INCREMENT,
   PRIMARY KEY (`id`)
-) ENGINE=MyISAM AUTO_INCREMENT=148 DEFAULT CHARSET=utf8;
+) ENGINE=MyISAM AUTO_INCREMENT=149 DEFAULT CHARSET=utf8;
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('showLogin','exploit.pl','Login','0','tables','main','147');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddFulltext','tables.pl','AddFulltext','5','tables','AddFulltext','62');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AnalyzeTable','tables.pl','AnalyzeTable','5','tables','AnalyzeTable','63');
@@ -54,6 +54,7 @@ INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values(
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowNewTable','tables.pl','ShowNewTable','5','tables','ShowNewTable','106');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveNewTable','tables.pl','SaveNewTable','5','tables','SaveNewTable','107');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('EditAction','tables.pl','EditAction','5','tables','EditAction','111');
+INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('showProfile','profile.pl','showProfile','5','','showProfile','148');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('MultipleDbAction','tables.pl','MultipleDbAction','5','tables','MultipleDbAction','118');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('RenameTable','tables.pl','RenameTable','5','tables','RenameTable','119');
 INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveNewColumn','tables.pl','SaveNewColumn','5','tables','SaveNewColumn','120');
@@ -86,7 +87,6 @@ CREATE TABLE `box` (
   PRIMARY KEY (`id`)
 ) ENGINE=MyISAM AUTO_INCREMENT=11 DEFAULT CHARSET=utf8;
 INSERT INTO `box` (`file`,`position`,`right`,`name`,`id`,`dynamic`) values('tables.pl','menuBar','5','database','10','right');
-
 CREATE TABLE `exploit` (
   `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
   `referer` text NOT NULL,
@@ -97,15 +97,7 @@ CREATE TABLE `exploit` (
   PRIMARY KEY (`id`),
   UNIQUE KEY `id` (`id`),
   FULLTEXT KEY `remote_addr` (`remote_addr`)
-) ENGINE=MyISAM DEFAULT CHARSET=utf8;
-
-CREATE TABLE `flood` (
-  `remote_addr` text NOT NULL,
-  `ti` text NOT NULL,
-  `id` int(11) NOT NULL AUTO_INCREMENT,
-  PRIMARY KEY (`id`)
-) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;
-
+) ENGINE=MyISAM AUTO_INCREMENT=40 DEFAULT CHARSET=utf8;
 CREATE TABLE `querys` (
   `title` varchar(100) NOT NULL DEFAULT '',
   `description` text NOT NULL,
@@ -114,7 +106,6 @@ CREATE TABLE `querys` (
   `id` int(11) NOT NULL AUTO_INCREMENT,
   PRIMARY KEY (`id`)
 ) ENGINE=MyISAM DEFAULT CHARSET=utf8;
-
 CREATE TABLE `reserved_words` (
   `reserved_word` varchar(50) DEFAULT NULL,
   `id` int(11) NOT NULL AUTO_INCREMENT,
@@ -343,23 +334,14 @@ INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VARBINARY','220');
 INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VARYING','221');
 INSERT INTO `reserved_words` (`reserved_word`,`id`) values('WHILE','222');
 INSERT INTO `reserved_words` (`reserved_word`,`id`) values('XOR','223');
-
 CREATE TABLE `users` (
   `pass` text NOT NULL,
   `user` varchar(10) NOT NULL,
-  `date` date NOT NULL DEFAULT '0000-00-00',
-  `email` varchar(25) NOT NULL,
   `right` int(1) NOT NULL DEFAULT '0',
-  `name` varchar(100) NOT NULL,
-  `firstname` varchar(20) NOT NULL,
-  `street` varchar(25) DEFAULT NULL,
-  `city` varchar(25) DEFAULT NULL,
-  `postcode` varchar(6) DEFAULT NULL,
-  `phone` varchar(20) DEFAULT NULL,
   `sid` varchar(200) DEFAULT NULL,
   `ip` varchar(50) DEFAULT NULL,
-  `cats` text,
   `id` int(11) NOT NULL AUTO_INCREMENT,
   PRIMARY KEY (`id`)
 ) ENGINE=MyISAM AUTO_INCREMENT=7 DEFAULT CHARSET=utf8;
-INSERT INTO `users` (`pass`,`user`,`date`,`email`,`right`,`name`,`firstname`,`street`,`city`,`postcode`,`phone`,`sid`,`ip`,`cats`,`id`) values('guest','guest','0000-00-00','guest@guestde','0','guest','guest','guest','guest','57072','445566','hghsdf7','dd','news','1');
+INSERT INTO `users` (`pass`,`user`,`right`,`sid`,`ip`,`id`) values('guest','guest','0','hghsdf7','dd','1');
+INSERT INTO `users` (`pass`,`user`,`right`,`sid`,`ip`,`id`) values('fe7374a18d3f8ca9547e49aa39a2dd67','admin','5','7856efbdf0d8bfc10933add28a2f62e4','127.0.0.1','2');
