@@ -31,7 +31,7 @@ $VAR1 = {
          'version'  => '0.62',
          'cgi'      => {
                    'bin'          => 'cgi-bin/',
-                   'style'        => 'lze',
+                   'style'        => 'mysql',
                    'serverName'   => 'http://localhost',
                    'cookiePath'   => '/',
                    'title'        => 'MySql::Admin',
